==> vdsm-4.40.40.tar.gz: vdsm-4.40.40/lib/vdsm/supervdsm_api/network.py <==
# Copyright 2016-2020 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#

from __future__ import absolute_import
from __future__ import division

from . import expose

from vdsm.network.api import (setSafeNetworkConfig, setupNetworks,
                              change_numvfs, network_caps, network_stats,
                              add_sourceroute, remove_sourceroute,
                              get_lldp_info)
from vdsm.network.sysctl import set_rp_filter_loose, set_rp_filter_strict
from vdsm.network.tc import setPortMirroring, unsetPortMirroring


expose(setSafeNetworkConfig)
expose(setupNetworks)
expose(network_caps)
expose(network_stats)
expose(change_numvfs)
expose(setPortMirroring)
expose(unsetPortMirroring)
expose(set_rp_filter_loose)
expose(set_rp_filter_strict)
expose(add_sourceroute)
expose(remove_sourceroute)
expose(get_lldp_info)

==> vdsm-4.50.0.tar.gz: vdsm-4.50.0/lib/vdsm/supervdsm_api/network.py <==
# Copyright 2016-2021 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#

from __future__ import absolute_import
from __future__ import division

from . import expose

from vdsm.network.api import (setSafeNetworkConfig, setupNetworks,
                              change_numvfs, network_caps, network_stats,
                              get_lldp_info, is_ovn_configured)
from vdsm.network.sysctl import set_rp_filter_loose, set_rp_filter_strict
from vdsm.network.tc import setPortMirroring, unsetPortMirroring


expose(setSafeNetworkConfig)
expose(setupNetworks)
expose(network_caps)
expose(network_stats)
expose(change_numvfs)
expose(setPortMirroring)
expose(unsetPortMirroring)
expose(set_rp_filter_loose)
expose(set_rp_filter_strict)
expose(get_lldp_info)
expose(is_ovn_configured)
